package sun.security.x509;

import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.io.OutputStream;
import java.util.ArrayList;
import sun.security.util.DerValue;
import java.io.IOException;
import java.util.Iterator;
import sun.security.util.DerOutputStream;
import java.util.List;

public class CertificatePoliciesExtension extends Extension implements CertAttrSet<String>
{
    public static final String IDENT = "x509.info.extensions.CertificatePolicies";
    public static final String NAME = "CertificatePolicies";
    public static final String POLICIES = "policies";
    private List<PolicyInformation> certPolicies;
    
    private void encodeThis() throws IOException {
        if (this.certPolicies == null || this.certPolicies.isEmpty()) {
            this.extensionValue = null;
        }
        else {
            DerOutputStream derOutputStream = new DerOutputStream();
            DerOutputStream derOutputStream2 = new DerOutputStream();
            Iterator<PolicyInformation> iterator = this.certPolicies.iterator();
            while (iterator.hasNext()) {
                ((PolicyInformation)iterator.next()).encode(derOutputStream2);
            }
            derOutputStream.write((byte)48, derOutputStream2);
            this.extensionValue = derOutputStream.toByteArray();
        }
    }
    
    public CertificatePoliciesExtension(List<PolicyInformation> list) throws IOException {
        this(Boolean.FALSE, list);
    }
    
    public CertificatePoliciesExtension(Boolean b, List<PolicyInformation> certPolicies) throws IOException {
        this.certPolicies = certPolicies;
        this.extensionId = PKIXExtensions.CertificatePolicies_Id;
        this.critical = (boolean)b;
        this.encodeThis();
    }
    
    public CertificatePoliciesExtension(Boolean b, Object o) throws IOException {
        this.extensionId = PKIXExtensions.CertificatePolicies_Id;
        this.critical = (boolean)b;
        this.extensionValue = (byte[])(byte[])o;
        DerValue derValue = new DerValue(this.extensionValue);
        if (derValue.tag != 48) {
            throw new IOException("Invalid encoding for CertificatePoliciesExtension.");
        }
        this.certPolicies = new ArrayList();
        while (derValue.data.available() != 0) {
            this.certPolicies.add(new PolicyInformation(derValue.data.getDerValue()));
        }
        return;
    }
    
    @Override
    public String toString() {
        if (this.certPolicies == null) {
            return "";
        }
        StringBuilder sb = new StringBuilder(super.toString());
        sb.append("CertificatePolicies [\n");
        Iterator<PolicyInformation> iterator = this.certPolicies.iterator();
        while (iterator.hasNext()) {
            sb.append(((PolicyInformation)iterator.next()).toString());
        }
        sb.append("]\n");
        return sb.toString();
    }
    
    @Override
    public void encode(OutputStream outputStream) throws IOException {
        DerOutputStream derOutputStream = new DerOutputStream();
        if (this.extensionValue == null) {
            this.extensionId = PKIXExtensions.CertificatePolicies_Id;
            this.critical = false;
            this.encodeThis();
        }
        super.encode(derOutputStream);
        outputStream.write(derOutputStream.toByteArray());
    }
    
    @Override
    public void set(String str, Object o) throws IOException {
        if (str.equalsIgnoreCase("policies")) {
            if (!(o instanceof List)) {
                throw new IOException("Attribute value should be of type List.");
            }
            this.certPolicies = (List)o;
            this.encodeThis();
            return;
        }
        else {
            throw new IOException("Attribute name [" + str + "] not recognized by CertAttrSet:CertificatePoliciesExtension.");
        }
    }
    
    @Override
    public List<PolicyInformation> get(String str) throws IOException {
        if (str.equalsIgnoreCase("policies")) {
            return this.certPolicies;
        }
        throw new IOException("Attribute name [" + str + "] not recognized by CertAttrSet:CertificatePoliciesExtension.");
    }
    
    @Override
    public void delete(String str) throws IOException {
        if (str.equalsIgnoreCase("policies")) {
            this.certPolicies = null;
            this.encodeThis();
            return;
        }
        throw new IOException("Attribute name [" + str + "] not recognized by CertAttrSet:CertificatePoliciesExtension.");
    }
    
    @Override
    public Enumeration<String> getElements() {
        AttributeNameEnumeration attributeNameEnumeration = new AttributeNameEnumeration();
        attributeNameEnumeration.addElement("policies");
        return attributeNameEnumeration.elements();
    }
    
    @Override
    public String getName() {
        return "CertificatePolicies";
    }
}
